@@ -213,6 +213,15 @@ class Pythonium(NodeVisitor):
         self._def_stack.pop()
         return node.name, name 
 
+    def visit_Slice(self, node):
+        start = self.visit(node.lower)
+        end = self.visit(node.upper)
+        step = self.visit(node.step)
+        return 'slice({}, {}, {})'.format(start, step, end)
+
+    def visit_Index(self, node):
+        return self.visit(node.value)
+
     def visit_Subscript(self, node):
         return "call({}, '__getitem__')({})".format(self.visit(node.value), self.visit(node.slice))
 
@@ -424,8 +433,16 @@ class Pythonium(NodeVisitor):
     def visit_Or(self, node):
         return '__or__'
 
+    def visit_Delete(self, node):
+        raise NotImplementedError
+
     def visit_Assign(self, node):
         value = self.visit(node.value)
+        if len(node.targets) == 1 and not isinstance(node.targets[0], Tuple):
+            target = self.visit(node.targets[0])
+            self.writer.write('{} = {};'.format(target, value))
+            return
+
         self.writer.write('var __assignement = {};'.format(value))
         for target in node.targets:
             if isinstance(target, Tuple):
@@ -503,7 +520,7 @@ class Pythonium(NodeVisitor):
             self.writer.push()
             list(map(self.visit, node.orelse))
             self.writer.pull()
-            self.write.write('}')
+            self.writer.write('}')
 
     def visit_Dict(self, node):
         a = []
