@@ -315,8 +315,11 @@ class Veloce(NodeVisitor):
             self.writer.write('if(!{}) {{ continue; }}'.format(' && '.join(map(self.visit, node.ifs))))
 
     def visit_While(self, node):
-        self.writer.write('while({}) {{'.format(node.test))
+        self.writer.write('while({}) {{'.format(self.visit(node.test)))
+        self.writer.push()
         list(map(self.visit, node.body))
+        self.writer.pull()
+        self.writer.write('}')
 
     def visit_AugAssign(self, node):
         target = self.visit(node.target)
@@ -406,15 +409,23 @@ class Veloce(NodeVisitor):
     def visit_Or(self, node):
         return '||'
 
+    def visit_Delete(self, node):
+        for target in node.targets:
+            target = self.visit(target)
+            self.writer.write('delete {};'.format(target))
+
     def visit_Assign(self, node):
-        target = node.targets[0]
         value = self.visit(node.value)
+        if len(node.targets) == 1 and not isinstance(node.targets[0], Tuple):
+            target = self.visit(node.targets[0])
+            self.writer.write('{} = {};'.format(target, value))
+            return
         self.writer.write('var __assignement = {};'.format(value))
         for target in node.targets:
             if isinstance(target, Tuple):
                 targets = map(self.visit, target.elts)
                 for index, target in enumerate(targets):
-                    self.writer.write('{} = __assignement[{}];\n'.format(target, index))
+                    self.writer.write('{} = __assignement[{}];'.format(target, index))
             else:
                 target = self.visit(target)
                 if self.in_classdef and len(self._function_stack) == 0:
